==> thoth-messaging-0.7.0.tar.gz: thoth-messaging-0.7.0/thoth/messaging/advise_justification.py <==
#!/usr/bin/env python3
# thoth-messaging
# Copyright(C) 2020 Francesco Murdaca
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


"""This is Thoth Messaging module for AdviseJustificationMessage."""

import logging

from .message_base import MessageBase, BaseMessageContents

_LOGGER = logging.getLogger(__name__)


class AdviseJustificationMessage(MessageBase):
    """Class used for Advise justification events on Kafka topic."""

    topic_name = "thoth.advise-reporter.advise-justification"

    class MessageContents(BaseMessageContents, serializer="json"):  # type: ignore
        """Class used to represent contents of a message Kafka topic."""

        message: str
        justification_type: str
        count: int

    def __init__(
        self,
        num_partitions: int = 1,
        replication_factor: int = 1,
        client_id: str = "thoth-messaging",
        ssl_auth: int = 1,
        bootstrap_server: str = "localhost:9092",
        topic_retention_time_second: int = 60 * 60 * 24 * 45,
        protocol: str = "SSL",
    ):
        """Initialize advise-justification topic."""
        super(AdviseJustificationMessage, self).__init__(
            topic_name=self.topic_name,
            value_type=self.MessageContents,
            num_partitions=num_partitions,
            replication_factor=replication_factor,
            client_id=client_id,
            ssl_auth=ssl_auth,
            bootstrap_server=bootstrap_server,
            topic_retention_time_second=topic_retention_time_second,
            protocol=protocol,
        )

==> thoth-messaging-0.11.2.tar.gz: thoth-messaging-0.11.2/thoth/messaging/advise_justification.py <==
#!/usr/bin/env python3
# thoth-messaging
# Copyright(C) 2020 Francesco Murdaca
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


"""This is Thoth Messaging module for AdviseJustificationMessage."""

import logging
import attr

from .message_base import MessageBase, BaseMessageContents

_LOGGER = logging.getLogger(__name__)


class AdviseJustificationMessage(MessageBase):
    """Class used for Advise justification events on Kafka topic."""

    base_name = "thoth.advise-reporter.advise-justification"

    @attr.s
    class MessageContents(BaseMessageContents):
        """Class used to represent contents of advise justification message Kafka topic."""

        message = attr.ib(type=str)
        justification_type = attr.ib(type=str)
        count = attr.ib(type=int)
        adviser_version = attr.ib(type=str)
        version = attr.ib(type=str, default="v1", init=False)

    def __init__(self,):
        """Initialize advise-justification topic."""
        super(AdviseJustificationMessage, self).__init__(
            base_name=self.base_name, value_type=self.MessageContents,
        )
